# pynus

A python library enabling to handle files in the NuSDaS format operationally used in the NWP systems in JMA.


## Disclaimer
This library is **NOT** an official project of JMA. Don't send any inquiries to JMA regarding this project.

## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.